@@ -4,7 +4,7 @@
 modname = 'leaflet'
 distname = 'cubicweb-leaflet'
 
-numversion = (0, 2, 0)
+numversion = (0, 2, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -40,7 +40,9 @@ data_files = [
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc', 'i18n', 'migration'):
+for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema',
+              'data', 'data/leafletcluster',
+              'wdoc', 'i18n', 'migration'):
     if isdir(dname):
         data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
 # Note: here, you'll need to add subdirectories if you want
